@@ -32,28 +32,30 @@ del FastCollateMixup
 del Mixup
 del cifarhundred_dataloader_dispatcher
 del cifarten_dataloader_dispatcher
+del data_prep_dispatcher_1ch
+del data_prep_dispatcher_3ch
 del fashionmnist_dataloader_dispatcher
 del imagenette_dataloader_dispatcher
 del mnist_dataloader_dispatcher
-del data_prep_dispatcher_1ch
-del data_prep_dispatcher_3ch
+del kmnist_dataloader_dispatcher
 
 # Deletions (from .distributed)
-del slurm_nccl_env
 del reduce_accumulate_keepalive
+del slurm_nccl_env
 
 # Deletions (from .nn)
 del ArgMaxLayer
-del BatchNorm2dRP
+del BasicAE
+del BasicVAE
 del BinarizeLayer
 del BrokenReLU
 del CausalConv1d
-del Conv2dRP
+del Clamp
 del ConvolutionalFlattenLayer
 del CoordConv1d
 del CoordConv2d
 del CoordConv3d
-del Dropout2dRP
+del DeepRBL
 del FCBlock
 del FCBlockLegacy
 del FieldTransform
@@ -66,39 +68,48 @@ del Mish
 del MultiSolvePoissonTensor
 del NNEnsemble
 del PoissonNetCifar
+del PreActResNet
 del ProbePrintLayer
+del RBLinear
+del ResBlock
 del ReshapeLayer
-del ScaledERF
 del SERLU
 del SGRUHCell
+del ScaledERF
 del SinLU
+del SirenSine
 del SmeLU
 del SolvePoisson
 del SolvePoissonTensor
 del WideResNet
-del PreActResNet
 del beta_reco_bce
+del build_repeated_sequential
 del field_transform
 del mishlayer_init
-del patch_rp_train_network
 del pixelwise_bce_mean
 del pixelwise_bce_sum
+del oldtranspose
 
 # Deletions (from .optim)
+del AdaBound
 del AdaHessian
+del AdamP
 del Adan
+del CosineLRScheduler
+del Lamb
 del Lion
 del Lookahead
 del Lookaround
 del RAdam
 del SAM
-del AdaBound
-del ralah_optim
-del wfneal
-del tricyc1c
+del SGDP
 del epochwise_onecycle
 del onecycle_lincos
 del onecycle_linlin
+del onecycle_linlin_updown
+del ralah_optim
+del tricyc1c
+del wfneal
 
 # Deletions (from .logging)
 del AverageMeter
