@@ -13,22 +13,26 @@
 # ------------------------------------------------------------------------------
 # Imports
 from .architectures import ArgMaxLayer
+from .architectures import BasicAE
+from .architectures import BasicVAE
 from .architectures import beta_reco_bce
 from .architectures import BinarizeLayer
+from .architectures import build_repeated_sequential
 from .architectures import CausalConv1d
+from .architectures import Clamp
+from .architectures import DeepRBL
 from .architectures import FCBlock
 from .architectures import FCBlockLegacy
 from .architectures import GaussianReparameterizerSampler
 from .architectures import InnerProduct
 from .architectures import pixelwise_bce_mean
 from .architectures import pixelwise_bce_sum
+from .architectures import RBLinear
+from .architectures import ResBlock
 from .architectures import SGRUHCell
+from .architectures import SirenSine
 from .architectures_resnets_dm import PreActResNet
 from .architectures_resnets_dm import WideResNet
-from .conv2drp import BatchNorm2dRP
-from .conv2drp import Conv2dRP
-from .conv2drp import Dropout2dRP
-from .conv2drp import patch_rp_train_network
 from .convolutional_flatten import ConvolutionalFlattenLayer
 from .coordconv import CoordConv1d
 from .coordconv import CoordConv2d
@@ -37,6 +41,7 @@ from .debuglayers import ProbePrintLayer
 from .fieldtransform import FieldTransform
 from .functional import field_transform
 from .functional import mish
+from .functional import oldtranspose
 from .kwta import BrokenReLU
 from .kwta import KWTA1d
 from .kwta import KWTA2d
@@ -58,7 +63,6 @@ from .utils import *
 # Deletions (from .)
 del architectures
 del architectures_resnets_dm
-del conv2drp
 del convolutional_flatten
 del coordconv
 del debuglayers
@@ -83,6 +87,7 @@ del AutoClipper
 del TA2ATAdapter
 del argser_f
 del argsink
+del no_op
 del download_gdrive
 del emplace_kv
 del subset_state_dict
